@@ -14,21 +14,24 @@ import gzip
 import tarfile
 
 from os import path
-from typing import List
+from typing import List, Union
 
 
-def read(file_path: str, upper: bool = True) -> List[fasta_object]:
+def read(
+    file_path: str, upper: bool = True, seq: bool = False
+) -> Union[List[fasta_object], List[str]]:
     """
     Reads a compressed or non-compressed fasta file and returns a list of fasta_objects.
     Zip, tar, gz, tar.gz files are supported.
     Attention: Encoding characters (backslash) will work under certain conditions.
 
     Input:
-        file_path: str, path to folder / file
-        upper: bool, cast sequence to upper-case letters.
+        file_path: str, path to folder / file.
+        upper: bool, cast sequences to upper-case letters.
+        seq: bool, return only the sequences.
 
     Returns:
-        fasta_objects: list of fasta_object
+        fasta_objects: list of fasta_object or list of strings.
     """
 
     if not path.isfile(file_path):
@@ -98,4 +101,8 @@ def read(file_path: str, upper: bool = True) -> List[fasta_object]:
                     body += addBody
             # append last element
             fasta_objects.append(fasta_object(head, body))
+
+    # Return only the sequences if required
+    if seq:
+        return [fo.body for fo in fasta_objects]
     return fasta_objects
